@@ -1,5 +1,6 @@
 # alias to keep the 'bytecode' variable free
 import bytecode as _bytecode
+
 try:
     from enum import IntFlag
 except ImportError:
@@ -13,22 +14,23 @@ class CompilerFlags(IntFlag):
     furthermore would be version dependent.
 
     """
-    OPTIMIZED             = 0x00001  # noqa
-    NEWLOCALS             = 0x00002  # noqa
-    VARARGS               = 0x00004  # noqa
-    VARKEYWORDS           = 0x00008  # noqa
-    NESTED                = 0x00010  # noqa
-    GENERATOR             = 0x00020  # noqa
-    NOFREE                = 0x00040  # noqa
+
+    OPTIMIZED = 0x00001  # noqa
+    NEWLOCALS = 0x00002  # noqa
+    VARARGS = 0x00004  # noqa
+    VARKEYWORDS = 0x00008  # noqa
+    NESTED = 0x00010  # noqa
+    GENERATOR = 0x00020  # noqa
+    NOFREE = 0x00040  # noqa
     # New in Python 3.5
     # Used for coroutines defined using async def ie native coroutine
-    COROUTINE             = 0x00080  # noqa
+    COROUTINE = 0x00080  # noqa
     # Used for coroutines defined as a generator and then decorated using
     # types.coroutine
-    ITERABLE_COROUTINE    = 0x00100  # noqa
+    ITERABLE_COROUTINE = 0x00100  # noqa
     # New in Python 3.6
     # Generator defined in an async def function
-    ASYNC_GENERATOR       = 0x00200  # noqa
+    ASYNC_GENERATOR = 0x00200  # noqa
 
     # __future__ flags
     FUTURE_GENERATOR_STOP = 0x80000  # noqa
@@ -52,41 +54,63 @@ def infer_flags(bytecode, is_async=None):
 
     """
     flags = CompilerFlags(0)
-    if not isinstance(bytecode, (_bytecode.Bytecode,
-                                 _bytecode.ConcreteBytecode,
-                                 _bytecode.ControlFlowGraph)):
-        msg = ('Expected a Bytecode, ConcreteBytecode or ControlFlowGraph '
-               'instance not %s')
+    if not isinstance(
+        bytecode,
+        (_bytecode.Bytecode, _bytecode.ConcreteBytecode, _bytecode.ControlFlowGraph),
+    ):
+        msg = (
+            "Expected a Bytecode, ConcreteBytecode or ControlFlowGraph "
+            "instance not %s"
+        )
         raise ValueError(msg % bytecode)
 
-    instructions = (bytecode.get_instructions()
-                    if isinstance(bytecode, _bytecode.ControlFlowGraph) else
-                    bytecode)
-    instr_names = {i.name for i in instructions
-                   if not isinstance(i, (_bytecode.SetLineno,
-                                         _bytecode.Label))}
+    instructions = (
+        bytecode.get_instructions()
+        if isinstance(bytecode, _bytecode.ControlFlowGraph)
+        else bytecode
+    )
+    instr_names = {
+        i.name
+        for i in instructions
+        if not isinstance(i, (_bytecode.SetLineno, _bytecode.Label))
+    }
 
     # Identify optimized code
-    if not (instr_names & {'STORE_NAME', 'LOAD_NAME', 'DELETE_NAME'}):
+    if not (instr_names & {"STORE_NAME", "LOAD_NAME", "DELETE_NAME"}):
         flags |= CompilerFlags.OPTIMIZED
 
     # Check for free variables
-    if not (instr_names & {'LOAD_CLOSURE', 'LOAD_DEREF', 'STORE_DEREF',
-                           'DELETE_DEREF', 'LOAD_CLASSDEREF'}):
+    if not (
+        instr_names
+        & {
+            "LOAD_CLOSURE",
+            "LOAD_DEREF",
+            "STORE_DEREF",
+            "DELETE_DEREF",
+            "LOAD_CLASSDEREF",
+        }
+    ):
         flags |= CompilerFlags.NOFREE
 
     # Copy flags for which we cannot infer the right value
-    flags |= bytecode.flags & (CompilerFlags.NEWLOCALS
-                               | CompilerFlags.VARARGS
-                               | CompilerFlags.VARKEYWORDS
-                               | CompilerFlags.NESTED)
+    flags |= bytecode.flags & (
+        CompilerFlags.NEWLOCALS
+        | CompilerFlags.VARARGS
+        | CompilerFlags.VARKEYWORDS
+        | CompilerFlags.NESTED
+    )
 
-    sure_generator = instr_names & {'YIELD_VALUE'}
-    maybe_generator = instr_names & {'YIELD_VALUE', 'YIELD_FROM'}
+    sure_generator = instr_names & {"YIELD_VALUE"}
+    maybe_generator = instr_names & {"YIELD_VALUE", "YIELD_FROM"}
 
-    sure_async = instr_names & {'GET_AWAITABLE', 'GET_AITER', 'GET_ANEXT',
-                                'BEFORE_ASYNC_WITH', 'SETUP_ASYNC_WITH',
-                                'END_ASYNC_FOR'}
+    sure_async = instr_names & {
+        "GET_AWAITABLE",
+        "GET_AITER",
+        "GET_ANEXT",
+        "BEFORE_ASYNC_WITH",
+        "SETUP_ASYNC_WITH",
+        "END_ASYNC_FOR",
+    }
 
     # If performing inference or forcing an async behavior, first inspect
     # the flags since this is the only way to identify iterable coroutines
@@ -99,10 +123,12 @@ def infer_flags(bytecode, is_async=None):
                 flags |= CompilerFlags.COROUTINE
         elif bytecode.flags & CompilerFlags.ITERABLE_COROUTINE:
             if sure_async:
-                msg = ("The ITERABLE_COROUTINE flag is set but bytecode that"
-                       "can only be used in async functions have been "
-                       "detected. Please unset that flag before performing "
-                       "inference.")
+                msg = (
+                    "The ITERABLE_COROUTINE flag is set but bytecode that"
+                    "can only be used in async functions have been "
+                    "detected. Please unset that flag before performing "
+                    "inference."
+                )
                 raise ValueError(msg)
             flags |= CompilerFlags.ITERABLE_COROUTINE
         elif bytecode.flags & CompilerFlags.ASYNC_GENERATOR:
@@ -137,9 +163,11 @@ def infer_flags(bytecode, is_async=None):
     # next set the GENERATOR flag if relevant
     else:
         if sure_async:
-            raise ValueError("The is_async argument is False but bytecodes "
-                             "that can only be used in async functions have "
-                             "been detected.")
+            raise ValueError(
+                "The is_async argument is False but bytecodes "
+                "that can only be used in async functions have "
+                "been detected."
+            )
 
         if maybe_generator:
             flags |= CompilerFlags.GENERATOR
