@@ -3,10 +3,18 @@ import textwrap
 import types
 import unittest
 
-from bytecode import (UNSET, Label, Instr, ConcreteInstr, BasicBlock,   # noqa
-                      Bytecode, ControlFlowGraph, ConcreteBytecode)
+from bytecode import (
+    UNSET,
+    Label,
+    Instr,
+    ConcreteInstr,
+    BasicBlock,  # noqa
+    Bytecode,
+    ControlFlowGraph,
+    ConcreteBytecode,
+)
 
-WORDCODE = (sys.version_info >= (3, 6))
+WORDCODE = sys.version_info >= (3, 6)
 
 
 def _format_instr_list(block, labels, lineno):
@@ -14,9 +22,9 @@ def _format_instr_list(block, labels, lineno):
     for instr in block:
         if not isinstance(instr, Label):
             if isinstance(instr, ConcreteInstr):
-                cls_name = 'ConcreteInstr'
+                cls_name = "ConcreteInstr"
             else:
-                cls_name = 'Instr'
+                cls_name = "Instr"
             arg = instr.arg
             if arg is not UNSET:
                 if isinstance(arg, Label):
@@ -26,20 +34,23 @@ def _format_instr_list(block, labels, lineno):
                 else:
                     arg = repr(arg)
                 if lineno:
-                    text = '%s(%r, %s, lineno=%s)' % (
-                        cls_name, instr.name, arg, instr.lineno)
+                    text = "%s(%r, %s, lineno=%s)" % (
+                        cls_name,
+                        instr.name,
+                        arg,
+                        instr.lineno,
+                    )
                 else:
-                    text = '%s(%r, %s)' % (cls_name, instr.name, arg)
+                    text = "%s(%r, %s)" % (cls_name, instr.name, arg)
             else:
                 if lineno:
-                    text = '%s(%r, lineno=%s)' % (
-                        cls_name, instr.name, instr.lineno)
+                    text = "%s(%r, lineno=%s)" % (cls_name, instr.name, instr.lineno)
                 else:
-                    text = '%s(%r)' % (cls_name, instr.name)
+                    text = "%s(%r)" % (cls_name, instr.name)
         else:
             text = labels[instr]
         instr_list.append(text)
-    return '[%s]' % ',\n '.join(instr_list)
+    return "[%s]" % ",\n ".join(instr_list)
 
 
 def dump_bytecode(code, lineno=False):
@@ -56,40 +67,40 @@ def dump_bytecode(code, lineno=False):
         else:
             block = code
 
-        indent = ' ' * 8
+        indent = " " * 8
         labels = {}
         for index, instr in enumerate(block):
             if isinstance(instr, Label):
-                name = 'label_instr%s' % index
+                name = "label_instr%s" % index
                 labels[instr] = name
 
         if is_concrete:
-            name = 'ConcreteBytecode'
-            print(indent + 'code = %s()' % name)
+            name = "ConcreteBytecode"
+            print(indent + "code = %s()" % name)
             if code.argcount:
-                print(indent + 'code.argcount = %s' % code.argcount)
+                print(indent + "code.argcount = %s" % code.argcount)
             if sys.version_info > (3, 8):
                 if code.posonlyargcount:
-                    print(indent + 'code.posonlyargcount = %s' % code.posonlyargcount)
+                    print(indent + "code.posonlyargcount = %s" % code.posonlyargcount)
             if code.kwonlyargcount:
-                print(indent + 'code.kwargonlycount = %s' % code.kwonlyargcount)
-            print(indent + 'code.flags = %#x' % code.flags)
+                print(indent + "code.kwargonlycount = %s" % code.kwonlyargcount)
+            print(indent + "code.flags = %#x" % code.flags)
             if code.consts:
-                print(indent + 'code.consts = %r' % code.consts)
+                print(indent + "code.consts = %r" % code.consts)
             if code.names:
-                print(indent + 'code.names = %r' % code.names)
+                print(indent + "code.names = %r" % code.names)
             if code.varnames:
-                print(indent + 'code.varnames = %r' % code.varnames)
+                print(indent + "code.varnames = %r" % code.varnames)
 
         for name in sorted(labels.values()):
-            print(indent + '%s = Label()' % name)
+            print(indent + "%s = Label()" % name)
 
         if is_concrete:
-            text = indent + 'code.extend('
-            indent = ' ' * len(text)
+            text = indent + "code.extend("
+            indent = " " * len(text)
         else:
-            text = indent + 'code = Bytecode('
-            indent = ' ' * len(text)
+            text = indent + "code = Bytecode("
+            indent = " " * len(text)
 
         lines = _format_instr_list(code, labels, lineno).splitlines()
         last_line = len(lines) - 1
@@ -97,7 +108,7 @@ def dump_bytecode(code, lineno=False):
             if index == 0:
                 print(text + lines[0])
             elif index == last_line:
-                print(indent + line + ')')
+                print(indent + line + ")")
             else:
                 print(indent + line)
 
@@ -106,12 +117,12 @@ def dump_bytecode(code, lineno=False):
         assert isinstance(code, ControlFlowGraph)
         labels = {}
         for block_index, block in enumerate(code):
-            labels[id(block)] = 'code[%s]' % block_index
+            labels[id(block)] = "code[%s]" % block_index
 
         for block_index, block in enumerate(code):
             text = _format_instr_list(block, labels, lineno)
             if block_index != len(code) - 1:
-                text += ','
+                text += ","
             print(text)
             print()
 
@@ -120,8 +131,9 @@ def get_code(source, *, filename="<string>", function=False):
     source = textwrap.dedent(source).strip()
     code = compile(source, filename, "exec")
     if function:
-        sub_code = [const for const in code.co_consts
-                    if isinstance(const, types.CodeType)]
+        sub_code = [
+            const for const in code.co_consts if isinstance(const, types.CodeType)
+        ]
         if len(sub_code) != 1:
             raise ValueError("unable to find function code")
         code = sub_code[0]
@@ -134,11 +146,11 @@ def disassemble(source, *, filename="<string>", function=False):
 
 
 class TestCase(unittest.TestCase):
-
     def assertBlocksEqual(self, code, *expected_blocks):
         self.assertEqual(len(code), len(expected_blocks))
 
         for block1, block2 in zip(code, expected_blocks):
             block_index = code.get_block_index(block1)
-            self.assertListEqual(list(block1), block2,
-                                 "Block #%s is different" % block_index)
+            self.assertListEqual(
+                list(block1), block2, "Block #%s is different" % block_index
+            )
