@@ -1,12 +1,16 @@
 #!/usr/bin/env python3
 import unittest
-from bytecode import (CompilerFlags, ConcreteBytecode, ConcreteInstr, Bytecode,
-                      ControlFlowGraph)
+from bytecode import (
+    CompilerFlags,
+    ConcreteBytecode,
+    ConcreteInstr,
+    Bytecode,
+    ControlFlowGraph,
+)
 from bytecode.flags import infer_flags
 
 
 class FlagsTests(unittest.TestCase):
-
     def test_type_validation_on_inference(self):
         with self.assertRaises(ValueError):
             infer_flags(1)
@@ -15,14 +19,23 @@ class FlagsTests(unittest.TestCase):
 
         # Check no loss of non-infered flags
         code = ControlFlowGraph()
-        code.flags |= (CompilerFlags.NEWLOCALS | CompilerFlags.VARARGS
-                       | CompilerFlags.VARKEYWORDS | CompilerFlags.NESTED
-                       | CompilerFlags.FUTURE_GENERATOR_STOP)
+        code.flags |= (
+            CompilerFlags.NEWLOCALS
+            | CompilerFlags.VARARGS
+            | CompilerFlags.VARKEYWORDS
+            | CompilerFlags.NESTED
+            | CompilerFlags.FUTURE_GENERATOR_STOP
+        )
         code.update_flags()
-        for f in (CompilerFlags.NEWLOCALS, CompilerFlags.VARARGS,
-                  CompilerFlags.VARKEYWORDS, CompilerFlags.NESTED,
-                  CompilerFlags.NOFREE, CompilerFlags.OPTIMIZED,
-                  CompilerFlags.FUTURE_GENERATOR_STOP):
+        for f in (
+            CompilerFlags.NEWLOCALS,
+            CompilerFlags.VARARGS,
+            CompilerFlags.VARKEYWORDS,
+            CompilerFlags.NESTED,
+            CompilerFlags.NOFREE,
+            CompilerFlags.OPTIMIZED,
+            CompilerFlags.FUTURE_GENERATOR_STOP,
+        ):
             self.assertTrue(bool(code.flags & f))
 
         # Infer optimized and nofree
@@ -30,11 +43,11 @@ class FlagsTests(unittest.TestCase):
         flags = infer_flags(code)
         self.assertTrue(bool(flags & CompilerFlags.OPTIMIZED))
         self.assertTrue(bool(flags & CompilerFlags.NOFREE))
-        code.append(ConcreteInstr('STORE_NAME', 1))
+        code.append(ConcreteInstr("STORE_NAME", 1))
         flags = infer_flags(code)
         self.assertFalse(bool(flags & CompilerFlags.OPTIMIZED))
         self.assertTrue(bool(flags & CompilerFlags.NOFREE))
-        code.append(ConcreteInstr('STORE_DEREF', 2))
+        code.append(ConcreteInstr("STORE_DEREF", 2))
         code.update_flags()
         self.assertFalse(bool(code.flags & CompilerFlags.OPTIMIZED))
         self.assertFalse(bool(code.flags & CompilerFlags.NOFREE))
@@ -44,21 +57,23 @@ class FlagsTests(unittest.TestCase):
 
         # Infer generator
         code = ConcreteBytecode()
-        code.append(ConcreteInstr('YIELD_VALUE'))
+        code.append(ConcreteInstr("YIELD_VALUE"))
         code.update_flags()
         self.assertTrue(bool(code.flags & CompilerFlags.GENERATOR))
 
         # Infer coroutine
         code = ConcreteBytecode()
-        code.append(ConcreteInstr('GET_AWAITABLE'))
+        code.append(ConcreteInstr("GET_AWAITABLE"))
         code.update_flags()
         self.assertTrue(bool(code.flags & CompilerFlags.COROUTINE))
 
         # Infer coroutine or async generator
-        for i, expected in (("YIELD_VALUE", CompilerFlags.ASYNC_GENERATOR),
-                            ("YIELD_FROM", CompilerFlags.COROUTINE)):
+        for i, expected in (
+            ("YIELD_VALUE", CompilerFlags.ASYNC_GENERATOR),
+            ("YIELD_FROM", CompilerFlags.COROUTINE),
+        ):
             code = ConcreteBytecode()
-            code.append(ConcreteInstr('GET_AWAITABLE'))
+            code.append(ConcreteInstr("GET_AWAITABLE"))
             code.append(ConcreteInstr(i))
             code.update_flags()
             self.assertTrue(bool(code.flags & expected))
@@ -72,8 +87,10 @@ class FlagsTests(unittest.TestCase):
         self.assertTrue(bool(code.flags & CompilerFlags.COROUTINE))
 
         # Infer coroutine or async generator
-        for i, expected in (("YIELD_VALUE", CompilerFlags.ASYNC_GENERATOR),
-                            ("YIELD_FROM", CompilerFlags.COROUTINE)):
+        for i, expected in (
+            ("YIELD_VALUE", CompilerFlags.ASYNC_GENERATOR),
+            ("YIELD_FROM", CompilerFlags.COROUTINE),
+        ):
             code = ConcreteBytecode()
             code.append(ConcreteInstr(i))
             code.update_flags(is_async=True)
@@ -84,14 +101,14 @@ class FlagsTests(unittest.TestCase):
 
         # Infer generator
         code = ConcreteBytecode()
-        code.append(ConcreteInstr('YIELD_VALUE'))
+        code.append(ConcreteInstr("YIELD_VALUE"))
         code.flags = CompilerFlags(CompilerFlags.COROUTINE)
         code.update_flags(is_async=False)
         self.assertTrue(bool(code.flags & CompilerFlags.GENERATOR))
 
         # Abort on coroutine
         code = ConcreteBytecode()
-        code.append(ConcreteInstr('GET_AWAITABLE'))
+        code.append(ConcreteInstr("GET_AWAITABLE"))
         code.flags = CompilerFlags(CompilerFlags.COROUTINE)
         with self.assertRaises(ValueError):
             code.update_flags(is_async=False)
@@ -103,33 +120,31 @@ class FlagsTests(unittest.TestCase):
 
             # Infer generator
             code = ConcreteBytecode()
-            code.append(ConcreteInstr('YIELD_VALUE'))
-            for f, expected in ((CompilerFlags.COROUTINE,
-                                 CompilerFlags.ASYNC_GENERATOR),
-                                (CompilerFlags.ASYNC_GENERATOR,
-                                 CompilerFlags.ASYNC_GENERATOR),
-                                (CompilerFlags.ITERABLE_COROUTINE,
-                                 CompilerFlags.ITERABLE_COROUTINE)):
+            code.append(ConcreteInstr("YIELD_VALUE"))
+            for f, expected in (
+                (CompilerFlags.COROUTINE, CompilerFlags.ASYNC_GENERATOR),
+                (CompilerFlags.ASYNC_GENERATOR, CompilerFlags.ASYNC_GENERATOR),
+                (CompilerFlags.ITERABLE_COROUTINE, CompilerFlags.ITERABLE_COROUTINE),
+            ):
                 code.flags = CompilerFlags(f)
                 code.update_flags(is_async=is_async)
                 self.assertTrue(bool(code.flags & expected))
 
             # Infer coroutine
             code = ConcreteBytecode()
-            code.append(ConcreteInstr('YIELD_FROM'))
-            for f, expected in ((CompilerFlags.COROUTINE,
-                                 CompilerFlags.COROUTINE),
-                                (CompilerFlags.ASYNC_GENERATOR,
-                                 CompilerFlags.COROUTINE),
-                                (CompilerFlags.ITERABLE_COROUTINE,
-                                 CompilerFlags.ITERABLE_COROUTINE)):
+            code.append(ConcreteInstr("YIELD_FROM"))
+            for f, expected in (
+                (CompilerFlags.COROUTINE, CompilerFlags.COROUTINE),
+                (CompilerFlags.ASYNC_GENERATOR, CompilerFlags.COROUTINE),
+                (CompilerFlags.ITERABLE_COROUTINE, CompilerFlags.ITERABLE_COROUTINE),
+            ):
                 code.flags = CompilerFlags(f)
                 code.update_flags(is_async=is_async)
                 self.assertTrue(bool(code.flags & expected))
 
             # Crash on ITERABLE_COROUTINE with async bytecode
             code = ConcreteBytecode()
-            code.append(ConcreteInstr('GET_AWAITABLE'))
+            code.append(ConcreteInstr("GET_AWAITABLE"))
             code.flags = CompilerFlags(CompilerFlags.ITERABLE_COROUTINE)
             with self.assertRaises(ValueError):
                 code.update_flags(is_async=is_async)
